/*
 * ShellWriter.java
 * 
 * Copyright 2003-2004 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.facade.io;

import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.UnsupportedEncodingException;

import net.sf.wickedshell.facade.descriptor.IShellDescriptor;

/**
 * @author Stefan Reichert
 * @since 13.05.2005
 */
public class ShellWriter {

	/** The <code>Reader</code> of the shell. */
	private final OutputStreamWriter shellWriter;
	/** The active <code>IShellDescriptor</code>. */
	private final IShellDescriptor activeShell;

	/**
	 * Constructor for ShellWriter.
	 */
	public ShellWriter(IShellDescriptor activeShell, OutputStream shellOutputStream)
			throws UnsupportedEncodingException {
		super();
		this.activeShell = activeShell;
		shellWriter = new OutputStreamWriter(shellOutputStream, activeShell.getCharacterEncoding());
	}

	/**
	 * Writes a command to the shellProcess.
	 * 
	 * @param command
	 *        The command to write
	 */
	public void writeCommand(String command) {
		try {
			shellWriter.write(command.toCharArray());
			shellWriter.write(activeShell.getLineFeedString());
			shellWriter.flush();
		}
		catch (IOException exception) {
			exception.printStackTrace();
		}
	}

	/**
	 * Deactivates the ShellWriter.
	 */
	public void deactivate() {
		try {
			shellWriter.flush();
			shellWriter.close();
		}
		catch (IOException exception) {
			exception.printStackTrace();
		}
	}

}
