/*
 * ChangeToFolderInShellAction.java
 * 
 * Copyright 2005-2006 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.jdt.action;

import net.sf.wickedshell.ShellID;
import net.sf.wickedshell.ui.shell.ShellView;

import org.eclipse.core.resources.IResource;
import org.eclipse.jdt.core.IJavaElement;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IWorkbenchPart;

/**
 * @author Stefan Reichert
 * @since 07.04.2006
 */
public class ChangeToFolderInShellAction implements IObjectActionDelegate {

	/** The currently selected <code>IResource</code>. */
	private IResource currentResource;
	/** The <code>IWorkbenchPart</code>. */
	private IWorkbenchPart targetPart;

	/**
	 * @see org.eclipse.ui.IObjectActionDelegate#setActivePart(org.eclipse.jface.action.IAction,
	 *      org.eclipse.ui.IWorkbenchPart)
	 */
	public void setActivePart(IAction action, IWorkbenchPart targetPart) {
		this.targetPart = targetPart;
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		ShellView shellView = (ShellView) targetPart.getSite().getPage().findView(
				ShellID.SHELL_VIEW_ID);
		if (shellView != null) {
			shellView.getShellViewer().getShellFacade().executeCommand(
					"cd " + currentResource.getLocation().toOSString());
		}
		else {
			MessageDialog.openInformation(targetPart.getSite().getShell(), "Wicked Shell",
					"The Shell is not open. Please open it first to change to the selected folder.");
		}
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		IStructuredSelection structuredSelection = (IStructuredSelection) selection;
		if (!structuredSelection.isEmpty()) {
			Object selectedElement = structuredSelection.getFirstElement();
			if (selectedElement instanceof IJavaElement) {
				IJavaElement currentJavaElement = (IJavaElement) selectedElement;
				if (currentJavaElement != null) {
					currentResource = currentJavaElement.getResource();
				}
				else {
					currentResource = null;
				}
				boolean exists = currentResource != null && currentResource.exists();
				action.setEnabled(exists && currentResource.getLocation().toFile().isDirectory());
			}
			else {
				action.setEnabled(false);
			}
		}
	}
}
