/*
 * BatchFileLabelProvider.java
 * 
 * Copyright 2003-2004 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.provider;

import java.io.File;

import net.sf.wickedshell.ShellPlugin;
import net.sf.wickedshell.domain.batch.IBatchFileDescriptor;
import net.sf.wickedshell.facade.descriptor.IShellDescriptor;
import net.sf.wickedshell.preferences.PreferenceHelper;
import net.sf.wickedshell.util.ResourceManager;

import org.eclipse.jface.viewers.IColorProvider;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Image;

/**
 * @author Stefan Reichert
 * @since 23.05.2005
 */
public class BatchFileLabelProvider extends LabelProvider implements ITableLabelProvider,
		IColorProvider {

	private static final int COLUMN_IMAGE = 0;
	private static final int COLUMN_FILE = 1;
	private static final int COLUMN_PARAMETERS = 2;

	/**
	 * Constructor for BatchFileLabelProvider.
	 */
	public BatchFileLabelProvider() {
		super();
	}

	/**
	 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnImage(java.lang.Object, int)
	 */
	public Image getColumnImage(Object element, int columnIndex) {
		switch (columnIndex) {
			case COLUMN_IMAGE:
				return ResourceManager.getPluginImage(ShellPlugin.getDefault(), "img/batch.gif");
			default:
				return null;
		}
	}

	/**
	 * @see org.eclipse.jface.viewers.ITableLabelProvider#getColumnText(java.lang.Object, int)
	 */
	public String getColumnText(Object element, int columnIndex) {
		IBatchFileDescriptor batchFileDescriptor = (IBatchFileDescriptor) element;
		switch (columnIndex) {
			case COLUMN_FILE:
				return batchFileDescriptor.getFilename();
			case COLUMN_PARAMETERS:
				return batchFileDescriptor.getParameters();
			default:
				return new String();
		}
	}

	/**
	 * @see org.eclipse.jface.viewers.IColorProvider#getForeground(java.lang.Object)
	 */
	public Color getForeground(Object element) {
		final IBatchFileDescriptor BatchFileDescriptor = (IBatchFileDescriptor) element;
		IShellDescriptor descriptor = PreferenceHelper.getActiveShellDescriptor();
		if (!descriptor.isAllowedForBatchList(new File(BatchFileDescriptor.getFilename()))) {
			return ResourceManager.getColor(SWT.COLOR_GRAY);
		}
		return null;
	}

	/**
	 * @see org.eclipse.jface.viewers.IColorProvider#getBackground(java.lang.Object)
	 */
	public Color getBackground(Object element) {
		return null;
	}

}
