/*
 * RunBatchFileInShellAction.java
 * 
 * Copyright 2005-2006 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.resource.action;

import net.sf.wickedshell.ShellID;
import net.sf.wickedshell.facade.descriptor.IShellDescriptor;
import net.sf.wickedshell.preferences.PreferenceHelper;
import net.sf.wickedshell.ui.shell.ShellView;

import org.eclipse.core.resources.IFile;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IObjectActionDelegate;
import org.eclipse.ui.IWorkbenchPart;

public class RunBatchFileInShellAction implements IObjectActionDelegate {

	/** The currently selected <code>IFolder</code>. */
	private IFile currentFile;
	/** The <code>IWorkbenchPart</code>. */
	private IWorkbenchPart targetPart;

	/**
	 * @see org.eclipse.ui.IObjectActionDelegate#setActivePart(org.eclipse.jface.action.IAction,
	 *      org.eclipse.ui.IWorkbenchPart)
	 */
	public void setActivePart(IAction action, IWorkbenchPart targetPart) {
		this.targetPart = targetPart;
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
	 */
	public void run(IAction action) {
		ShellView shellView = (ShellView) targetPart.getSite().getPage().findView(
				ShellID.SHELL_VIEW_ID);
		if (shellView != null) {
			targetPart.getSite().getPage().activate(shellView);
			shellView.getShellViewer().getShellFacade().executeCommand(
					currentFile.getRawLocation().toOSString());
		}
		else {
			MessageDialog.openInformation(targetPart.getSite().getShell(), "Wicked Shell",
					"The Shell is not open. Please open it first to run the selected Batch File.");
		}
	}

	/**
	 * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
	 *      org.eclipse.jface.viewers.ISelection)
	 */
	public void selectionChanged(IAction action, ISelection selection) {
		IStructuredSelection structuredSelection = (IStructuredSelection) selection;
		if (!structuredSelection.isEmpty()) {
			currentFile = (IFile) structuredSelection.getFirstElement();
			boolean validFile = currentFile.exists();
			IShellDescriptor descriptor = PreferenceHelper.getActiveShellDescriptor();
			action.setEnabled(validFile
					&& descriptor.isExecutable(currentFile.getRawLocation().toFile()));
		}
	}
}
