/*
 * EncodingPrinter.java
 * 
 * Copyright 2005-2006 Stefan Reichert.
 * All Rights Reserved.
 * 
 * This software is the proprietary information of Stefan Reichert.
 * Use is subject to license terms.
 * 
 */
package net.sf.wickedshell.util;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;

import net.sf.wickedshell.ShellID;

/**
 * @author Stefan Reichert
 * @since 04.07.2006
 */
public class EncodingPrinter {

	public static final void printEncoding(char[] character) {
		for (int index = 0; index < character.length; index++) {
			printEncoding(character[index]);
		}
	}

	public static final void printEncoding(char character) {
		printEncoding(character, ShellID.ENCODING_ISO_8859_1);
		printEncoding(character, ShellID.ENCODING_US_ASCII);
		printEncoding(character, ShellID.ENCODING_UTF_8);
		printEncoding(character, ShellID.ENCODING_UTF_16_BE);
		printEncoding(character, ShellID.ENCODING_UTF_16_LE);
		printEncoding(character, ShellID.ENCODING_CP_1252);
	}

	private static final void printEncoding(char character, String encoding) {
		try {
			int characterInt = (int) character;

			if (characterInt < 0 || characterInt > 127) {
				ByteArrayOutputStream encodedStream = new ByteArrayOutputStream();
				OutputStreamWriter encodedWriter = new OutputStreamWriter(encodedStream, encoding);
				encodedWriter.write(character);
				encodedWriter.flush();
				int encodedCharacterInt = new Integer(encodedStream.toByteArray()[0]).intValue();

				System.out.print("Character: ");
				System.out.print(character);
				System.out.print(" ;Hex : ");
				System.out.print(Integer.toHexString(characterInt));
				System.out.print(" (");
				System.out.print(characterInt);
				System.out.print(");Hex (coverted to ");
				System.out.print(encodedWriter.getEncoding());
				System.out.print("): ");
				System.out.print(Integer.toHexString(encodedCharacterInt));
				System.out.print(" (");
				System.out.print(encodedCharacterInt);
				System.out.println(")");
				encodedWriter.close();
			}
		}
		catch (IOException exception) {
			exception.printStackTrace();
		}
	}

	public static final void printEncoding(byte[] characterBytes) {
		for (int index = 0; index < characterBytes.length; index++) {
			printEncoding(characterBytes[index]);
		}
	}

	public static final void printEncoding(byte characterByte) {
		printEncoding(characterByte, ShellID.ENCODING_ISO_8859_1);
		printEncoding(characterByte, ShellID.ENCODING_US_ASCII);
		printEncoding(characterByte, ShellID.ENCODING_UTF_8);
		printEncoding(characterByte, ShellID.ENCODING_UTF_16_BE);
		printEncoding(characterByte, ShellID.ENCODING_UTF_16_LE);
		printEncoding(characterByte, ShellID.ENCODING_CP_1252);
	}

	private static final void printEncoding(byte characterByte, String encoding) {
		try {
			int characterInt = new Integer(characterByte).intValue();
			if (characterInt < 0 || characterInt > 127) {
				ByteArrayOutputStream encodedStream = new ByteArrayOutputStream();
				OutputStreamWriter encodedWriter = new OutputStreamWriter(encodedStream, encoding);
				encodedWriter.write(characterInt);
				encodedWriter.flush();
				int encodedCharacterInt = new Integer(encodedStream.toByteArray()[0]).intValue();

				System.out.print("Character: ");
				System.out.print((char) characterByte);
				System.out.print(" Hex: ");
				System.out.print(Integer.toHexString(characterInt));
				System.out.print(" (");
				System.out.print(characterInt);
				System.out.print(");Hex ( ");
				System.out.print(encodedWriter.getEncoding());
				System.out.print("): ");
				System.out.print(Integer.toHexString(encodedCharacterInt));
				System.out.print(" (");
				System.out.print(encodedCharacterInt);
				System.out.println(")");
				encodedWriter.close();
			}
		}
		catch (IOException exception) {
			exception.printStackTrace();
		}
	}

}
